@@ -387,9 +387,9 @@ editing_open(struct lu_module *module, const char *file_suffix,
 	backup_name = g_strconcat(e->filename, "-", NULL);
 	fd = open_and_copy_file(e->filename, backup_name, FALSE, error);
 	g_free (backup_name);
-	close(fd);
 	if (fd == -1)
 		goto err_fscreate;
+	close(fd);
 
 	e->new_filename = g_strconcat(e->filename, "+", NULL);
 	e->new_fd = open_and_copy_file(e->filename, e->new_filename, TRUE,
@@ -534,7 +534,7 @@ parse_field(const struct format_specifier *format, GValue *value,
 						 string, &err);
 	if (ret == FALSE) {
 		g_assert(err != NULL);
-		g_warning(lu_strerror(err));
+		g_warning("%s", lu_strerror(err));
 		lu_error_free(&err);
 	}
 	return ret;
@@ -1501,7 +1501,7 @@ generic_lock(struct lu_module *module, const char *file_suffix, int field,
 	     struct lu_ent *ent, enum lock_op op, struct lu_error **error)
 {
 	struct editing *e;
-	char *value, *new_value, *name;
+	char *value, *new_value, *name = NULL;
 	gboolean commit = FALSE, ret = FALSE;
 
 	/* Get the name which keys the entries of interest in the file. */
@@ -1561,7 +1561,7 @@ generic_is_locked(struct lu_module *module, const char *file_suffix,
 		  int field, struct lu_ent *ent, struct lu_error **error)
 {
 	char *filename;
-	char *value, *name;
+	char *value, *name = NULL;
 	int fd;
 	gboolean ret = FALSE;
 
@@ -1752,7 +1752,7 @@ generic_setpass(struct lu_module *module, const char *file_suffix, int field,
 		struct lu_error **error)
 {
 	struct editing *e;
-	char *value, *name;
+	char *value, *name = NULL;
 	gboolean ret = FALSE;
 
 	/* Get the name of this account. */
